California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 024 - REPEALS RECENT LEGISLATION THAT WOULD ALLOW BUSINESSES TO CARRY BACK LOSSES, SHARE TAX CREDITS, AND USE A SALES-BASED INCOME CALCULATION TO LOWER TAXABLE INCOME. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1325746 | CALIFORNIA HEALTHCARE INSTITUTE ISSUES COMMITTEE - NO ON PROPOSITION 24 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1324078 | YES ON 24, THE TAX FAIRNESS ACT SPONSORED BY TAXPAYERS AND PUBLIC EMPLOYEE GROUPS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1324906 | NO ON 24 - STOP THE JOBS TAX, A COALITION OF TAXPAYERS, EMPLOYERS, SMALL BUSINESSES, EDUCATORS AND HIGH TECH AND BIOTECHNOLOGY ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1331815 | CALIFORNIA ALLIANCE ACTION FUND: A COMMITTEE SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS FOR PROPOSITIONS 24, 25 AND AGAINST PROPOSITIONS 23, 26 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1332741 | SILICON VALLEY LEADERSHIP GROUP'S SAVE CALIFORNIA JOBS NOW - NO ON PROPOSITION 23 AND NO ON PROPOSITION 24, AND YES ON SANTA CLARA COUNY MEASURE B | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1332721 | LOS ANGELES COUNTY FEDERATION OF LABOR, AFL-CIO, YES ON 24 AND 25 | SUPPORT